@@ -375,15 +375,15 @@ testthat::test_that(
     )
 
     testthat::expect_equal(
-      long_to_wide_converter(df1, condition, score, paired = FALSE),
-      long_to_wide_converter(df, condition, score, id, paired = FALSE)
+      long_to_wide_converter(df1, "condition", score, paired = FALSE),
+      long_to_wide_converter(df, condition, "score", id, paired = FALSE)
     )
 
     testthat::expect_equal(
-      long_to_wide_converter(df1, condition, score, paired = FALSE, spread = FALSE) %>%
+      long_to_wide_converter(df1, condition, "score", paired = FALSE, spread = FALSE) %>%
         dplyr::arrange(rowid) %>%
         dplyr::select(-rowid),
-      long_to_wide_converter(df, condition, score, id, paired = FALSE, spread = FALSE) %>%
+      long_to_wide_converter(df, condition, score, "id", paired = FALSE, spread = FALSE) %>%
         dplyr::arrange(rowid) %>%
         dplyr::select(-rowid)
     )
@@ -391,7 +391,7 @@ testthat::test_that(
     testthat::expect_equal(
       long_to_wide_converter(df1, condition, score, spread = FALSE) %>%
         dplyr::arrange(rowid),
-      long_to_wide_converter(df, condition, score, id, spread = FALSE) %>%
+      long_to_wide_converter(df, condition, score, "id", spread = FALSE) %>%
         dplyr::arrange(rowid)
     )
   }
@@ -414,23 +414,23 @@ testthat::test_that(
     )
 
     testthat::expect_equal(
-      long_to_wide_converter(df1, condition, desire, paired = FALSE) %>%
+      long_to_wide_converter(df1, "condition", desire, paired = FALSE) %>%
         dplyr::select(-rowid),
-      long_to_wide_converter(df, condition, desire, subject, paired = FALSE) %>%
+      long_to_wide_converter(df, condition, "desire", subject, paired = FALSE) %>%
         dplyr::select(-rowid)
     )
 
     testthat::expect_equal(
       long_to_wide_converter(df1, condition, desire, paired = FALSE, spread = FALSE) %>%
         dplyr::select(-rowid),
-      long_to_wide_converter(df, condition, desire, subject, paired = FALSE, spread = FALSE) %>%
+      long_to_wide_converter(df, condition, desire, "subject", paired = FALSE, spread = FALSE) %>%
         dplyr::select(-rowid)
     )
 
     testthat::expect_equal(
-      long_to_wide_converter(df1, condition, desire, spread = FALSE) %>%
+      long_to_wide_converter(df1, condition, "desire", spread = FALSE) %>%
         dplyr::select(-rowid),
-      long_to_wide_converter(df, condition, desire, subject, spread = FALSE) %>%
+      long_to_wide_converter(df, "condition", desire, subject, spread = FALSE) %>%
         dplyr::select(-rowid)
     )
   }
